@@ -9,6 +9,7 @@
 
 
 
+#include "hackerlab/bugs/panic.h"
 #include "hackerlab/mem/mem.h"
 #include "hackerlab/char/char-class.h"
 #include "hackerlab/char/str.h"
@@ -85,10 +86,36 @@ str_length_n (const t_uchar * x, size_t n)
  * 
  */
 
+/*(c str_hash)
+ * unsigned long str_hash (const t_uchar * chr, size_t len);
+ * 
+ * Compute an `unsigned long' hash value for a 0-terminated string.
+ * This computes the same hash value as
+ *
+ *	 str_hash_n (chr, str_length (chr));
+ *
+ */
+unsigned long
+str_hash (const t_uchar * chr)
+{
+  unsigned long result;
+
+  result = 0;
+  while (*chr)
+    {
+      result = *chr + (result << 3) + (result >> (8 * sizeof (result) - 3));
+      ++chr;
+    }
+
+  return result;
+}
+
+
 /*(c str_hash_n)
  * unsigned long str_hash_n (const t_uchar * chr, size_t len);
  * 
- * Compute an `unsigned long' hash value for a string.
+ * Compute an `unsigned long' hash value for a string of the indicated
+ * length..
  */
 unsigned long
 str_hash_n (const t_uchar * chr, size_t len)
@@ -319,13 +346,15 @@ str_cmp_n (const t_uchar * a, size_t a_l, const t_uchar * b, size_t b_l)
 
       ac = *a++;
       bc = *b++;
-      if (ac < bc)
-	return -1;
-      else if (ac > bc)
-	return 1;
-      else if (!ac)
-	return 0;
-      --l;
+      if (ac == bc)
+        {
+          --l;
+          continue;
+        }
+      else
+        {
+          return ((ac < bc) ? -1 : 1);
+        }
     }
   if (a_l < b_l)
     return -1;
@@ -369,6 +398,47 @@ str_cmp_prefix (const t_uchar * prefix, const t_uchar * s)
   return 0;
 }
 
+
+/*(c str_cmp_prefix_n)
+ * int str_cmp_prefix_n (const t_uchar * prefix,
+ *                       size_t prefix_len,
+ *                       const t_uchar * s,
+ *                       size_t s_len);
+ *
+ * Compare strings `prefix' and `s', of the indicated lengths.  If
+ * `prefix' is a prefix of `s', return 0.  Otherwise, if `prefix' is
+ * lexically first, return -1; if `s' is lexically first, return 1.
+ */
+int
+str_cmp_prefix_n (const t_uchar * prefix,
+                  size_t prefix_len,
+                  const t_uchar * s,
+                  size_t s_len)
+{
+  if (!prefix_len)
+    return 0;
+
+  if (!s_len)
+    return 1;
+
+  while (prefix_len && s_len)
+    {
+      if (*s < *prefix)
+	return 1;
+      else if (*s > *prefix)
+	return -1;
+      else
+        {
+          ++prefix;
+          ++s;
+          --prefix_len;
+          --s_len;
+        }
+    }
+
+  return !!prefix_len;
+}
+
 
 /************************************************************************
  *(h2 "String Comparisons Ignoring Case")
@@ -479,6 +549,49 @@ str_casecmp_prefix (const t_uchar * prefix, const t_uchar * s)
   return 0;
 }
 
+
+
+/*(c str_casecmp_prefix_n)
+ * int str_casecmp_prefix_n (const t_uchar * prefix,
+ *                           size_t prefix_len,
+ *                           const t_uchar * s,
+ *                           size_t s_len);
+ * 
+ * Compare strings `prefix' and `s', of the indicated lengths,
+ * ignoring case.  If `prefix' is a prefix of `s', return 0.
+ * Otherwise, if `prefix' is lexically first, return -1; if `s' is
+ * lexically first, return 1.
+ */
+int
+str_casecmp_prefix_n (const t_uchar * prefix,
+                      size_t prefix_len,
+                      const t_uchar * s,
+                      size_t s_len)
+{
+  if (!prefix_len)
+    return 0;
+
+  if (!s_len)
+    return 1;
+
+  while (prefix_len && s_len)
+    {
+      if (char_to_lower(*s) < char_to_lower (*prefix))
+	return 1;
+      else if (char_to_lower (*s) > char_to_lower (*prefix))
+	return -1;
+      else
+        {
+          ++prefix;
+          ++s;
+          --prefix_len;
+          --s_len;
+        }
+    }
+
+  return !!prefix_len;
+}
+
 
 /************************************************************************
  *(h2 "String Copying")
@@ -541,8 +654,7 @@ str_cpy_n (t_uchar * to,
 	  --n;
 	}
     }
-  while (n--)
-    *to++ = 0;
+  *to++ = 0;
   return answer;
 }
 
@@ -629,7 +741,7 @@ str_cat_n (t_uchar * to,
 
 
 /*(c str_save)
- * t_uchar * strsav (alloc_limits limits, const t_uchar * str);
+ * t_uchar * str_save (alloc_limits limits, const t_uchar * str);
  * 
  * Allocate a copy of the 0-terminated string `str'.
  *
@@ -643,6 +755,9 @@ str_save (alloc_limits limits, const t_uchar * str)
   size_t len;
 
   len = str_length (str);
+
+  invariant (len + 1);
+
   it = (t_uchar *)lim_malloc (limits, len + 1);
   if (!it)
     return 0;
@@ -669,6 +784,98 @@ str_save_n (alloc_limits limits,
 {
   t_uchar * it;
 
+  invariant (len + 1);
+
+  it = (t_uchar *)lim_malloc (limits, len + 1);
+  if (!it)
+    return 0;
+  mem_move (it, str, len);
+  it[len] = 0;
+  return it;
+}
+
+
+/*(c str_save_trimming)
+ * t_uchar * str_save_trimming (alloc_limits limits, const t_uchar * str);
+ * 
+ * Allocate a copy of the 0-terminated string `str', discarding
+ * leading and trailing whitespace from the copy.
+ *
+ * Allocate storage according to `limits'.  (See xref:"Allocation
+ * With Limitations".)
+ */
+t_uchar *
+str_save_trimming (alloc_limits limits, const t_uchar * str)
+{
+  const t_uchar * start;
+  const t_uchar * scan;
+  const t_uchar * end;
+  size_t len;
+  t_uchar * it;
+
+  if (!str)
+    start = scan = end = 0;
+  else
+    {
+      for (start = str; *start && char_is_space (*start); ++start)
+        ;
+
+      end = start;
+      for (scan = start; *scan; ++scan)
+        {
+          if (!char_is_space (*scan))
+            end = scan + 1;
+        }
+    }
+
+  len = (end - start);
+
+  invariant (len + 1);
+
+  it = (t_uchar *)lim_malloc (limits, len + 1);
+  if (!it)
+    return 0;
+  mem_move (it, start, len);
+  it[len] = 0;
+  return it;
+}
+
+
+/*(c str_save_trimming_n)
+ * t_uchar * str_save_trimming_n (alloc_limits limits,
+ *                                const t_uchar * str,
+ *                                size_t len);
+ * 
+ * Allocate a copy of the n-byte string `str'.  Leading and
+ * trailing whitespace are discarded from the copy (which may
+ * therefore be of length less than `n').
+ * 
+ * The copy includes a trailing 0.
+ *
+ * Allocate storage according to `limits'.  (See xref:"Allocation
+ * With Limitations".)
+ */
+t_uchar *
+str_save_trimming_n (alloc_limits limits,
+                     const t_uchar * str,
+                     size_t len)
+{
+  t_uchar * it;
+
+  while (len && char_is_space (*str))
+    {
+      ++str;
+      --len;
+    }
+
+  while (len && char_is_space (str[len - 1]))
+    {
+      --len;
+    }
+
+
+  invariant (len + 1);
+
   it = (t_uchar *)lim_malloc (limits, len + 1);
   if (!it)
     return 0;
