@@ -51,56 +51,56 @@ vu_sys_free_closure (void * closure)
 
 
 /*(c vu_sys_access)
- * int vu_sys_access (int * errn, char * path, int mode, void * closure);
+ * int vu_sys_access (int * errn, const char * path, int mode, void * closure);
  * 
  * Call `access'.
  */
 int
-vu_sys_access (int * errn, char * path, int mode, void * closure)
+vu_sys_access (int * errn, const char * path, int mode, void * closure)
 {
   int rv;
   rv = access (path, mode);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_chdir)
- * int vu_sys_chdir (int * errn, char * path, void * closure);
+ * int vu_sys_chdir (int * errn, const char * path, void * closure);
  * 
  * Call `chdir'.
  */
 int
-vu_sys_chdir (int * errn, char * path, void * closure)
+vu_sys_chdir (int * errn, const char * path, void * closure)
 {
   int rv;
   rv = chdir (path);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_chmod)
- * int vu_sys_chmod (int * errn, char * path, int mode, void * closure);
+ * int vu_sys_chmod (int * errn, const char * path, int mode, void * closure);
  * 
  * Call `chmod'.
  */
 int
-vu_sys_chmod (int * errn, char * path, int mode, void * closure)
+vu_sys_chmod (int * errn, const char * path, int mode, void * closure)
 {
   int rv;
   rv = chmod (path, mode);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_chown)
  * int vu_sys_chown (int * errn,
- *                   char * path,
+ *                   const char * path,
  *                   int owner,
  *                   int group,
  *                   void * closure);
@@ -109,7 +109,7 @@ vu_sys_chmod (int * errn, char * path, int mode, void * closure)
  */
 int
 vu_sys_chown (int * errn,
-	      char * path,
+	      const char * path,
 	      int owner,
 	      int group,
 	      void * closure)
@@ -117,23 +117,23 @@ vu_sys_chown (int * errn,
   int rv;
   rv = chown (path, owner, group);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_chroot)
- * int vu_sys_chroot (int * errn, char * path, void * closure);
+ * int vu_sys_chroot (int * errn, const char * path, void * closure);
  * 
  * Call `chroot'.
  */
 int
-vu_sys_chroot (int * errn, char * path, void * closure)
+vu_sys_chroot (int * errn, const char * path, void * closure)
 {
   int rv;
   rv = chroot (path);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -149,7 +149,7 @@ vu_sys_closedir (int * errn, DIR * dir, void * closure)
   int rv;
   rv = closedir (dir);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -165,7 +165,7 @@ vu_sys_close (int * errn, int fd, void * closure)
   int rv;
   rv = close (fd);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -181,7 +181,7 @@ vu_sys_fchdir (int * errn, int fd, void * closure)
   int rv;
   rv = fchdir (fd);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -197,7 +197,7 @@ vu_sys_fchmod (int * errn, int fd, int mode, void * closure)
   int rv;
   rv = fchmod (fd, mode);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -221,7 +221,7 @@ vu_sys_fchown (int * errn,
   int rv;
   rv = fchown (fd, owner, group);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -243,7 +243,7 @@ vu_sys_fstat (int * errn,
   int rv;
   rv = fstat (fd, buf);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -258,7 +258,7 @@ vu_sys_fsync (int * errn, int fd, void * closure)
   int rv;
   rv = fsync (fd);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -273,23 +273,23 @@ vu_sys_ftruncate (int * errn, int fd, off_t where, void * closure)
   int rv;
   rv = ftruncate (fd, where);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_link)
- * int vu_sys_link (int * errn, char * from, char * to, void * closure);
+ * int vu_sys_link (int * errn, const char * from, const char * to, void * closure);
  * 
  * Call `link'.
  */
 int
-vu_sys_link (int * errn, char * from, char * to, void * closure)
+vu_sys_link (int * errn, const char * from, const char * to, void * closure)
 {
   int rv;
   rv = link (from, to);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -313,14 +313,14 @@ vu_sys_lseek (int * errn,
   off_t rv;
   rv = lseek (fd, offset, whence);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_lstat)
  * int vu_sys_lstat (int * errn,
- *                   char * path,
+ *                   const char * path,
  *                   struct stat * buf,
  *                   void * closure);
  * 
@@ -328,37 +328,37 @@ vu_sys_lseek (int * errn,
  */
 int
 vu_sys_lstat (int * errn,
-	      char * path,
+	      const char * path,
 	      struct stat * buf,
 	      void * closure)
 {
   int rv;
   rv = lstat (path, buf);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_mkdir)
- * int vu_sys_mkdir (int * errn, char * path, int mode, void * closure);
+ * int vu_sys_mkdir (int * errn, const char * path, int mode, void * closure);
  * 
  * Call `mkdir'.
  */
 int
-vu_sys_mkdir (int * errn, char * path, int mode, void * closure)
+vu_sys_mkdir (int * errn, const char * path, int mode, void * closure)
 {
   int rv;
   rv = mkdir (path, mode);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_open)
  * int vu_sys_open (int * errn,
- *                  char * path,
+ *                  const char * path,
  *                  int flags,
  *                  int mode,
  *                  void * closure);
@@ -367,7 +367,7 @@ vu_sys_mkdir (int * errn, char * path, int mode, void * closure)
  */
 int
 vu_sys_open (int * errn,
-	     char * path,
+	     const char * path,
 	     int flags,
 	     int mode,
 	     void * closure)
@@ -375,7 +375,7 @@ vu_sys_open (int * errn,
   int rv;
   rv = open (path, flags, mode);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -383,7 +383,7 @@ vu_sys_open (int * errn,
 /*(c vu_sys_opendir)
  * int vu_sys_opendir (int * errn,
  *                     DIR ** retv,
- *                     char * path,
+ *                     const char * path,
  *                     void * closure);
  * 
  * Call `opendir'.
@@ -391,12 +391,12 @@ vu_sys_open (int * errn,
 int
 vu_sys_opendir (int * errn,
 		DIR ** retv,
-		char * path,
+		const char * path,
 		void * closure)
 {
   *retv = opendir (path);
   if (!*retv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return (*retv == 0 ? -1 : 0);
 }
 
@@ -420,7 +420,7 @@ vu_sys_read (int * errn,
   ssize_t rv;
   rv = read (fd, buf, count);
   if (rv == -1)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -446,7 +446,7 @@ vu_sys_readdir (int * errn,
   de = readdir (dir);
   if (!de)
     {
-      *errn = errno;
+      if (errn) *errn = errno;
       return -1;
     }
 
@@ -455,7 +455,7 @@ vu_sys_readdir (int * errn,
       *file_ret = str_save (limits, de->d_name);
       if (!*file_ret)
 	{
-	  *errn = ENOMEM;
+	  if (errn) *errn = ENOMEM;
 	  return -1;
 	}
     }
@@ -465,7 +465,7 @@ vu_sys_readdir (int * errn,
 
 /*(c vu_sys_readlink)
  * int vu_sys_readlink (int * errn,
- *                      char * path,
+ *                      const char * path,
  *                      char * buf,
  *                      int bufsize,
  *                      void * closure);
@@ -474,7 +474,7 @@ vu_sys_readdir (int * errn,
  */
 int
 vu_sys_readlink (int * errn,
-		 char * path,
+		 const char * path,
 		 char * buf,
 		 int bufsize,
 		 void * closure)
@@ -482,44 +482,44 @@ vu_sys_readlink (int * errn,
   int rv;
   rv = readlink (path, buf, bufsize);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 /*(c vu_sys_rename)
- * int vu_sys_rename (int * errn, char * from, char * to, void * closure);
+ * int vu_sys_rename (int * errn, const char * from, const char * to, void * closure);
  * 
  * Call `rename'.
  */
 int
-vu_sys_rename (int * errn, char * from, char * to, void * closure)
+vu_sys_rename (int * errn, const char * from, const char * to, void * closure)
 {
   int rv;
   rv = rename (from, to);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 /*(c vu_sys_rmdir)
- * int vu_sys_rmdir (int * errn, char * path, void * closure);
+ * int vu_sys_rmdir (int * errn, const char * path, void * closure);
  * 
  * Call `rmdir'.
  */
 int
-vu_sys_rmdir (int * errn, char * path, void * closure)
+vu_sys_rmdir (int * errn, const char * path, void * closure)
 {
   int rv;
   rv = rmdir (path);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_stat)
  * int vu_sys_stat (int * errn,
- *                  char * path,
+ *                  const char * path,
  *                  struct stat * buf,
  *                  void * closure);
  * 
@@ -527,37 +527,37 @@ vu_sys_rmdir (int * errn, char * path, void * closure)
  */
 int
 vu_sys_stat (int * errn,
-	     char * path,
+	     const char * path,
 	     struct stat * buf,
 	     void * closure)
 {
   int rv;
   rv = stat (path, buf);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_symlink)
- * int vu_sys_symlink (int * errn, char * from, char * to, void * closure);
+ * int vu_sys_symlink (int * errn, const char * from, const char * to, void * closure);
  * 
  * Call `symlink'.
  */
 int
-vu_sys_symlink (int * errn, char * from, char * to, void * closure)
+vu_sys_symlink (int * errn, const char * from, const char * to, void * closure)
 {
   int rv;
   rv = symlink (from, to);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_truncate)
  * int vu_sys_truncate (int * errn,
- *                      char * path,
+ *                      const char * path,
  *                      off_t where,
  *                      void * closure);
  * 
@@ -565,37 +565,37 @@ vu_sys_symlink (int * errn, char * from, char * to, void * closure)
  */
 int
 vu_sys_truncate (int * errn,
-		 char * path,
+		 const char * path,
 		 off_t where,
 		 void * closure)
 {
   int rv;
   rv = truncate (path, where);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_unlink)
- * int vu_sys_unlink (int * errn, char * path, void * closure);
+ * int vu_sys_unlink (int * errn, const char * path, void * closure);
  * 
  * Call `unlink'.
  */
 int
-vu_sys_unlink (int * errn, char * path, void * closure)
+vu_sys_unlink (int * errn, const char * path, void * closure)
 {
   int rv;
   rv = unlink (path);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
 
 /*(c vu_sys_utime)
  * int vu_sys_utime (int * errn,
- *                   char * path,
+ *                   const char * path,
  *                   struct utimbuf * times,
  *                   void * closure);
  * 
@@ -603,14 +603,14 @@ vu_sys_unlink (int * errn, char * path, void * closure)
  */
 int
 vu_sys_utime (int * errn,
-	      char * path,
+	      const char * path,
 	      struct utimbuf * times,
 	      void * closure)
 {
   int rv;
   rv = utime (path, times);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -618,7 +618,7 @@ vu_sys_utime (int * errn,
 /*(c vu_sys_write)
  * ssize_t vu_sys_write (int * errn,
  *                       int fd,
- *                       char * buf,
+ *                       const char * buf,
  *                       size_t count,
  *                       void * closure);
  * 
@@ -627,7 +627,7 @@ vu_sys_utime (int * errn,
 ssize_t
 vu_sys_write (int * errn,
 	      int fd,
-	      char * buf,
+	      const char * buf,
 	      size_t count,
 	      void * closure)
 {
@@ -645,7 +645,7 @@ vu_sys_write (int * errn,
 
   rv = write (fd, buf, count);
   if (rv == -1)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -669,7 +669,7 @@ vu_sys_fcntl (int * errn,
   int rv;
   rv = fcntl (fd, cmd, arg);
   if (rv)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -685,7 +685,7 @@ vu_sys_dup (int * errn, int fd, void * closure)
   int rv;
   rv = dup (fd);
   if (rv == -1)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
@@ -701,7 +701,7 @@ vu_sys_dup2 (int * errn, int fd, int newfd, void * closure)
   int rv;
   rv = dup2 (fd, newfd);
   if (rv == -1)
-    *errn = errno;
+    if (errn) *errn = errno;
   return rv;
 }
 
