@@ -295,8 +295,8 @@ static struct vu_handler default_handler = { &_vu_system_fs_vtable, 0 };
  */
 
 /*(c vu_push_name_handler)
- * void vu_push_name_handler (t_uchar * name,
- *			      t_uchar ** doc,
+ * void vu_push_name_handler (const t_uchar * name,
+ *			      const t_uchar ** doc,
  *			      regex_t * preg,
  *			      int eflags,
  *			      struct vu_fs_discipline * vtable,
@@ -334,8 +334,8 @@ static struct vu_handler default_handler = { &_vu_system_fs_vtable, 0 };
  * `vu_enable_optional_name_handler'.
  */
 void
-vu_push_name_handler (t_uchar * name,
-		      t_uchar ** doc,
+vu_push_name_handler (const t_uchar * name,
+		      const t_uchar ** doc,
 		      regex_t * preg,
 		      int eflags,
 		      struct vu_fs_discipline * vtable,
@@ -358,7 +358,7 @@ vu_push_name_handler (t_uchar * name,
 
 
 /*(c vu_enable_optional_name_handler)
- * int vu_enable_optional_name_handler (t_uchar * name);
+ * int vu_enable_optional_name_handler (const t_uchar * name);
  *
  * Push the named namespace handler on the VU namespace stack.
  *
@@ -368,7 +368,7 @@ vu_push_name_handler (t_uchar * name,
  * Return 0 on success, -1 if the named handler was not found.
  */
 int
-vu_enable_optional_name_handler (t_uchar * name)
+vu_enable_optional_name_handler (const t_uchar * name)
 {
   int x;
   int len;
@@ -491,7 +491,7 @@ vu_move_state (int * errn, int fd, int newfd)
  * (See xref:"vu_handler".)
  */
 struct vu_handler *
-vu_path_dispatch (char * path)
+vu_path_dispatch (const char * path)
 {
   int x;
   for (x = ar_size (_vu_fs_handlers.void_ptr, lim_use_must_malloc, sizeof (*_vu_fs_handlers.nhp)) - 1; x >= 0; --x)
@@ -625,12 +625,12 @@ vu_dir_dispatch (DIR * dir)
  */
 
 /*(c vu_access)
- * int vu_access (int * errn, char * path, int mode);
+ * int vu_access (int * errn, const char * path, int mode);
  * 
  * See the manual page for `access'.
  */
 int
-vu_access (int * errn, char * path, int mode)
+vu_access (int * errn, const char * path, int mode)
 {
   struct vu_handler * handler;
 
@@ -640,12 +640,12 @@ vu_access (int * errn, char * path, int mode)
 
 
 /*(c vu_chdir)
- * int vu_chdir (int * errn, char * path);
+ * int vu_chdir (int * errn, const char * path);
  * 
  * See the manual page for `chdir'.
  */
 int
-vu_chdir (int * errn, char * path)
+vu_chdir (int * errn, const char * path)
 {
   struct vu_handler * handler;
 
@@ -655,12 +655,12 @@ vu_chdir (int * errn, char * path)
 
 
 /*(c vu_chmod)
- * int vu_chmod (int * errn, char * path, int mode);
+ * int vu_chmod (int * errn, const char * path, int mode);
  * 
  * See the manual page for `chmod'.
  */
 int
-vu_chmod (int * errn, char * path, int mode)
+vu_chmod (int * errn, const char * path, int mode)
 {
   struct vu_handler * handler;
 
@@ -670,12 +670,12 @@ vu_chmod (int * errn, char * path, int mode)
 
 
 /*(c vu_chown)
- * int vu_chown (int * errn, char * path, int owner, int group);
+ * int vu_chown (int * errn, const char * path, int owner, int group);
  * 
  * See the manual page for `chown'.
  */
 int
-vu_chown (int * errn, char * path, int owner, int group)
+vu_chown (int * errn, const char * path, int owner, int group)
 {
   struct vu_handler * handler;
 
@@ -685,12 +685,12 @@ vu_chown (int * errn, char * path, int owner, int group)
 
 
 /*(c vu_chroot)
- * int vu_chroot (int * errn, char * path);
+ * int vu_chroot (int * errn, const char * path);
  * 
  * See the manual page for `chroot'.
  */
 int
-vu_chroot (int * errn, char * path)
+vu_chroot (int * errn, const char * path)
 {
   struct vu_handler * handler;
 
@@ -850,12 +850,12 @@ vu_ftruncate (int * errn, int fd, off_t where)
 
 
 /*(c vu_link)
- * int vu_link (int * errn, char * from, char * to);
+ * int vu_link (int * errn, const char * from, const char * to);
  * 
  * See the manual page for `link'.
  */
 int
-vu_link (int * errn, char * from, char * to)
+vu_link (int * errn, const char * from, const char * to)
 {
   struct vu_handler * handler;
   struct vu_handler * handler2;
@@ -865,7 +865,7 @@ vu_link (int * errn, char * from, char * to)
   if (   (handler->vtable->link != handler2->vtable->link)
       || (handler->closure != handler2->closure))
     {
-      *errn = EXDEV;
+      if (errn) *errn = EXDEV;
       return -1;
     }
   return handler->vtable->link(errn, from, to, handler->closure);
@@ -888,12 +888,12 @@ vu_lseek (int * errn, int fd, off_t offset, int whence)
 
 
 /*(c vu_lstat)
- * int vu_lstat (int * errn, char * path, struct stat * buf);
+ * int vu_lstat (int * errn, const char * path, struct stat * buf);
  * 
  * See the manual page for `lstat'.
  */
 int
-vu_lstat (int * errn, char * path, struct stat * buf)
+vu_lstat (int * errn, const char * path, struct stat * buf)
 {
   struct vu_handler * handler;
 
@@ -903,12 +903,12 @@ vu_lstat (int * errn, char * path, struct stat * buf)
 
 
 /*(c vu_mkdir)
- * int vu_mkdir (int * errn, char * path, int mode);
+ * int vu_mkdir (int * errn, const char * path, int mode);
  * 
  * See the manual page for `mkdir'.
  */
 int
-vu_mkdir (int * errn, char * path, int mode)
+vu_mkdir (int * errn, const char * path, int mode)
 {
   struct vu_handler * handler;
 
@@ -918,12 +918,12 @@ vu_mkdir (int * errn, char * path, int mode)
 
 
 /*(c vu_open)
- * int vu_open (int * errn, char * path, int flags, int mode);
+ * int vu_open (int * errn, const char * path, int flags, int mode);
  * 
  * See the manual page for `open'.
  */
 int
-vu_open (int * errn, char * path, int flags, int mode)
+vu_open (int * errn, const char * path, int flags, int mode)
 {
   struct vu_handler * handler;
   int fd;
@@ -965,12 +965,12 @@ vu_dir_fd (DIR * dir)
 
 
 /*(c vu_opendir)
- * int vu_opendir (int * errn, DIR ** retv,  char * path);
+ * int vu_opendir (int * errn, DIR ** retv,  const char * path);
  * 
  * See the manual page for `opendir'.
  */
 int
-vu_opendir (int * errn, DIR ** retv,  char * path)
+vu_opendir (int * errn, DIR ** retv,  const char * path)
 {
   struct vu_handler * handler;
   int fd;
@@ -1072,12 +1072,12 @@ vu_readdir (int * errn,
 
 
 /*(c vu_readlink)
- * int vu_readlink (int * errn, char * path, char * buf, int bufsize);
+ * int vu_readlink (int * errn, const char * path, char * buf, int bufsize);
  * 
  * See the manual page for `readlink'.
  */
 int
-vu_readlink (int * errn, char * path, char * buf, int bufsize)
+vu_readlink (int * errn, const char * path, char * buf, int bufsize)
 {
   struct vu_handler * handler;
 
@@ -1087,12 +1087,12 @@ vu_readlink (int * errn, char * path, char * buf, int bufsize)
 
 
 /*(c vu_rename)
- * int vu_rename (int * errn, char * from, char * to);
+ * int vu_rename (int * errn, const char * from, const char * to);
  * 
  * See the manual page for `rename'.
  */
 int
-vu_rename (int * errn, char * from, char * to)
+vu_rename (int * errn, const char * from, const char * to)
 {
   struct vu_handler * handler;
   struct vu_handler * handler2;
@@ -1102,7 +1102,7 @@ vu_rename (int * errn, char * from, char * to)
   if (   (handler->vtable->rename != handler2->vtable->rename)
       || (handler->closure != handler2->closure))
     {
-      *errn = EXDEV;
+      if (errn) *errn = EXDEV;
       return -1;
     }
   return handler->vtable->rename(errn, from, to, handler->closure);
@@ -1110,12 +1110,12 @@ vu_rename (int * errn, char * from, char * to)
 
 
 /*(c vu_rmdir)
- * int vu_rmdir (int * errn, char * path);
+ * int vu_rmdir (int * errn, const char * path);
  * 
  * See the manual page for `rmdir'.
  */
 int
-vu_rmdir (int * errn, char * path)
+vu_rmdir (int * errn, const char * path)
 {
   struct vu_handler * handler;
 
@@ -1125,12 +1125,12 @@ vu_rmdir (int * errn, char * path)
 
 
 /*(c vu_stat)
- * int vu_stat (int * errn, char * path, struct stat * buf);
+ * int vu_stat (int * errn, const char * path, struct stat * buf);
  * 
  * See the manual page for `stat'.
  */
 int
-vu_stat (int * errn, char * path, struct stat * buf)
+vu_stat (int * errn, const char * path, struct stat * buf)
 {
   struct vu_handler * handler;
 
@@ -1140,12 +1140,12 @@ vu_stat (int * errn, char * path, struct stat * buf)
 
 
 /*(c vu_symlink)
- * int vu_symlink (int * errn, char * from, char * to);
+ * int vu_symlink (int * errn, const char * from, const char * to);
  * 
  * See the manual page for `symlink'.
  */
 int
-vu_symlink (int * errn, char * from, char * to)
+vu_symlink (int * errn, const char * from, const char * to)
 {
   struct vu_handler * handler;
   struct vu_handler * handler2;
@@ -1155,7 +1155,7 @@ vu_symlink (int * errn, char * from, char * to)
   if (   (handler->vtable->symlink != handler2->vtable->symlink)
       || (handler->closure != handler2->closure))
     {
-      *errn = EXDEV;
+      if (errn) *errn = EXDEV;
       return -1;
     }
   return handler->vtable->symlink(errn, from, to, handler->closure);
@@ -1164,12 +1164,12 @@ vu_symlink (int * errn, char * from, char * to)
 
 
 /*(c vu_truncate)
- * int vu_truncate (int * errn, char * path, off_t where);
+ * int vu_truncate (int * errn, const char * path, off_t where);
  * 
  * See the manual page for `truncate'.
  */
 int
-vu_truncate (int * errn, char * path, off_t where)
+vu_truncate (int * errn, const char * path, off_t where)
 {
   struct vu_handler * handler;
 
@@ -1179,12 +1179,12 @@ vu_truncate (int * errn, char * path, off_t where)
 
 
 /*(c vu_unlink)
- * int vu_unlink (int * errn, char * path);
+ * int vu_unlink (int * errn, const char * path);
  * 
  * See the manual page for `unlink'.
  */
 int
-vu_unlink (int * errn, char * path)
+vu_unlink (int * errn, const char * path)
 {
   struct vu_handler * handler;
 
@@ -1194,12 +1194,12 @@ vu_unlink (int * errn, char * path)
 
 
 /*(c vu_utime)
- * int vu_utime (int * errn, char * path, struct utimbuf *times);
+ * int vu_utime (int * errn, const char * path, struct utimbuf *times);
  * 
  * See the manual page for `utime'.
  */
 int
-vu_utime (int * errn, char * path, struct utimbuf * times)
+vu_utime (int * errn, const char * path, struct utimbuf * times)
 {
   struct vu_handler * handler;
 
@@ -1209,12 +1209,12 @@ vu_utime (int * errn, char * path, struct utimbuf * times)
 
 
 /*(c vu_write)
- * ssize_t vu_write (int * errn, int fd, char * buf, size_t count);
+ * ssize_t vu_write (int * errn, int fd, const char * buf, size_t count);
  * 
  * See the manual page for `write'.
  */
 ssize_t
-vu_write (int * errn, int fd, char * buf, size_t count)
+vu_write (int * errn, int fd, const char * buf, size_t count)
 {
   struct vu_handler * handler;
 
@@ -1224,7 +1224,7 @@ vu_write (int * errn, int fd, char * buf, size_t count)
 
 
 /*(c vu_write_retry)
- * ssize_t vu_write_retry (int * errn, int fd, char * buf, size_t count);
+ * ssize_t vu_write_retry (int * errn, int fd, const char * buf, size_t count);
  * 
  * Use `vu_write' to write to `fd'.  Write repeatedly (even if a write
  * returns early from EINTR or EAGAIN) until `count' characters are
@@ -1233,7 +1233,7 @@ vu_write (int * errn, int fd, char * buf, size_t count)
  * Return the number of characters written or -1 on error.
  */
 ssize_t
-vu_write_retry (int * errn, int fd, char * buf, size_t count)
+vu_write_retry (int * errn, int fd, const char * buf, size_t count)
 {
   size_t orig_count;
 
