@@ -53,15 +53,15 @@
  VU_FS_NAME##c (free_closure, prefix, middle, suffix, \
 		    void, (void * closure)) punct \
  VU_FS_NAME##c (access, prefix, middle, suffix, \
-		    int, (int * errn, char * path, int mode, void * closure)) punct \
+		    int, (int * errn, const char * path, int mode, void * closure)) punct \
  VU_FS_NAME##c (chdir, prefix, middle, suffix, \
-		    int, (int * errn, char * path, void * closure)) punct \
+		    int, (int * errn, const char * path, void * closure)) punct \
  VU_FS_NAME##c (chmod, prefix, middle, suffix, \
-		    int, (int * errn, char * path, int mode, void * closure)) punct \
+		    int, (int * errn, const char * path, int mode, void * closure)) punct \
  VU_FS_NAME##c (chown, prefix, middle, suffix, \
-		    int, (int * errn, char * path, int owner, int group, void * closure)) punct \
+		    int, (int * errn, const char * path, int owner, int group, void * closure)) punct \
  VU_FS_NAME##c (chroot, prefix, middle, suffix, \
-		    int, (int * errn, char * path, void * closure)) punct \
+		    int, (int * errn, const char * path, void * closure)) punct \
  VU_FS_NAME##c (close, prefix, middle, suffix, \
 		    int, (int * errn, int fd, void * closure)) punct \
  VU_FS_NAME##c (closedir, prefix, middle, suffix, \
@@ -79,41 +79,41 @@
  VU_FS_NAME##c (ftruncate, prefix, middle, suffix, \
 		    int, (int * errn, int fd, off_t where, void * closure)) punct \
  VU_FS_NAME##c (link, prefix, middle, suffix, \
-		    int, (int * errn, char * from, char * to, void * closure)) punct \
+		    int, (int * errn, const char * from, const char * to, void * closure)) punct \
  VU_FS_NAME##c (lseek, prefix, middle, suffix, \
 		    off_t, (int * errn, int fd, off_t offset, int whence, void * closure)) punct \
  VU_FS_NAME##c (lstat, prefix, middle, suffix, \
-		    int, (int * errn, char * path, struct stat * buf, void * closure)) punct \
+		    int, (int * errn, const char * path, struct stat * buf, void * closure)) punct \
  VU_FS_NAME##c (mkdir, prefix, middle, suffix, \
-		    int, (int * errn, char * path, int mode, void * closure)) punct \
+		    int, (int * errn, const char * path, int mode, void * closure)) punct \
  VU_FS_NAME##c (open, prefix, middle, suffix, \
-		    int, (int * errn, char * path, int flags, int mode, void * closure)) punct \
+		    int, (int * errn, const char * path, int flags, int mode, void * closure)) punct \
  VU_FS_NAME##c (opendir, prefix, middle, suffix, \
-		    int, (int * errn, DIR ** retv,  char * path, void * closure)) punct \
+		    int, (int * errn, DIR ** retv,  const char * path, void * closure)) punct \
  VU_FS_NAME##c (read, prefix, middle, suffix, \
 		    ssize_t, \
 		    (int * errn, int fd, char * buf, size_t count, void * closure)) punct \
  VU_FS_NAME##c (readdir, prefix, middle, suffix, \
 		    int, (int * errn, struct alloc_limits * lims, char ** file, DIR * dir, void * closure)) punct \
  VU_FS_NAME##c (readlink, prefix, middle, suffix, \
-		    int, (int * errn, char * path, char * buf, int bufsize, void * closure)) punct \
+		    int, (int * errn, const char * path, char * buf, int bufsize, void * closure)) punct \
  VU_FS_NAME##c (rename, prefix, middle, suffix, \
-		    int, (int * errn, char * from, char * to, void * closure)) punct \
+		    int, (int * errn, const char * from, const char * to, void * closure)) punct \
  VU_FS_NAME##c (rmdir, prefix, middle, suffix, \
-		    int, (int * errn, char * path, void * closure)) punct \
+		    int, (int * errn, const char * path, void * closure)) punct \
  VU_FS_NAME##c (stat, prefix, middle, suffix, \
-		    int, (int * errn, char * path, struct stat * buf, void * closure)) punct \
+		    int, (int * errn, const char * path, struct stat * buf, void * closure)) punct \
  VU_FS_NAME##c (symlink, prefix, middle, suffix, \
-		    int, (int * errn, char * from, char * to, void * closure)) punct \
+		    int, (int * errn, const char * from, const char * to, void * closure)) punct \
  VU_FS_NAME##c (truncate, prefix, middle, suffix, \
-		    int, (int * errn, char * path, off_t where, void * closure)) punct \
+		    int, (int * errn, const char * path, off_t where, void * closure)) punct \
  VU_FS_NAME##c (unlink, prefix, middle, suffix, \
-		    int, (int * errn, char * path, void * closure)) punct \
+		    int, (int * errn, const char * path, void * closure)) punct \
  VU_FS_NAME##c (utime, prefix, middle, suffix, \
-		    int, (int * errn, char * path, struct utimbuf * times, void * closure)) punct \
+		    int, (int * errn, const char * path, struct utimbuf * times, void * closure)) punct \
  VU_FS_NAME##c (write, prefix, middle, suffix, \
 		    ssize_t, \
-		    (int * errn, int fd, char * buf, size_t count, void * closure)) punct \
+		    (int * errn, int fd, const char * buf, size_t count, void * closure)) punct \
  VU_FS_NAME##c (fcntl, prefix, middle, suffix, \
 		    int, (int * errn, int fd, int cmd, long arg, void * closure)) punct \
  VU_FS_NAME##c (dup, prefix, middle, suffix, \
@@ -209,8 +209,8 @@ struct _vu_namespace_handler
   regex_t * preg;
   int eflags;
   struct vu_handler handler;
-  t_uchar * name;
-  t_uchar ** doc;
+  const t_uchar * name;
+  const t_uchar ** doc;
 };
 
 
@@ -222,27 +222,27 @@ extern union _t_vu_fs_handlers _vu_optional_fs_handlers;
 
 
 /* automatically generated __STDC__ prototypes */
-extern void vu_push_name_handler (t_uchar * name,
-				  t_uchar ** doc,
-				  regex_t * preg,
-				  int eflags,
-				  struct vu_fs_discipline * vtable,
-				  void * closure,
-				  int is_optional);
-extern int vu_enable_optional_name_handler (t_uchar * name);
+extern void vu_push_name_handler (const t_uchar * name,
+                                  const t_uchar ** doc,
+                                  regex_t * preg,
+                                  int eflags,
+                                  struct vu_fs_discipline * vtable,
+                                  void * closure,
+                                  int is_optional);
+extern int vu_enable_optional_name_handler (const t_uchar * name);
 extern void vu_set_fd_handler (int fd,
-			       struct vu_fs_discipline * vtable,
-			       void * closure);
+                               struct vu_fs_discipline * vtable,
+                               void * closure);
 extern void vu_reinit_after_unexec (void);
 extern int vu_move_state (int * errn, int fd, int newfd);
-extern struct vu_handler * vu_path_dispatch (char * path);
+extern struct vu_handler * vu_path_dispatch (const char * path);
 extern struct vu_handler * vu_fd_dispatch (int fd);
 extern struct vu_handler * vu_dir_dispatch (DIR * dir);
-extern int vu_access (int * errn, char * path, int mode);
-extern int vu_chdir (int * errn, char * path);
-extern int vu_chmod (int * errn, char * path, int mode);
-extern int vu_chown (int * errn, char * path, int owner, int group);
-extern int vu_chroot (int * errn, char * path);
+extern int vu_access (int * errn, const char * path, int mode);
+extern int vu_chdir (int * errn, const char * path);
+extern int vu_chmod (int * errn, const char * path, int mode);
+extern int vu_chown (int * errn, const char * path, int owner, int group);
+extern int vu_chroot (int * errn, const char * path);
 extern int vu_close (int * errn, int fd);
 extern int vu_closedir (int * errn, DIR * dir);
 extern int vu_fchdir (int * errn, int fd);
@@ -251,29 +251,29 @@ extern int vu_fchown (int * errn, int fd, int owner, int group);
 extern int vu_fstat (int * errn, int fd, struct stat * buf);
 extern int vu_fsync (int * errn, int fd);
 extern int vu_ftruncate (int * errn, int fd, off_t where);
-extern int vu_link (int * errn, char * from, char * to);
+extern int vu_link (int * errn, const char * from, const char * to);
 extern off_t vu_lseek (int * errn, int fd, off_t offset, int whence);
-extern int vu_lstat (int * errn, char * path, struct stat * buf);
-extern int vu_mkdir (int * errn, char * path, int mode);
-extern int vu_open (int * errn, char * path, int flags, int mode);
+extern int vu_lstat (int * errn, const char * path, struct stat * buf);
+extern int vu_mkdir (int * errn, const char * path, int mode);
+extern int vu_open (int * errn, const char * path, int flags, int mode);
 extern int vu_dir_fd (DIR * dir);
-extern int vu_opendir (int * errn, DIR ** retv,  char * path);
+extern int vu_opendir (int * errn, DIR ** retv,  const char * path);
 extern ssize_t vu_read (int * errn, int fd, char * buf, size_t count);
 extern ssize_t vu_read_retry (int * errn, int fd, char * buf, size_t count);
 extern int vu_readdir (int * errn,
-		       struct alloc_limits * limits,
-		       char ** file_ret,
-		       DIR * dir);
-extern int vu_readlink (int * errn, char * path, char * buf, int bufsize);
-extern int vu_rename (int * errn, char * from, char * to);
-extern int vu_rmdir (int * errn, char * path);
-extern int vu_stat (int * errn, char * path, struct stat * buf);
-extern int vu_symlink (int * errn, char * from, char * to);
-extern int vu_truncate (int * errn, char * path, off_t where);
-extern int vu_unlink (int * errn, char * path);
-extern int vu_utime (int * errn, char * path, struct utimbuf * times);
-extern ssize_t vu_write (int * errn, int fd, char * buf, size_t count);
-extern ssize_t vu_write_retry (int * errn, int fd, char * buf, size_t count);
+                       struct alloc_limits * limits,
+                       char ** file_ret,
+                       DIR * dir);
+extern int vu_readlink (int * errn, const char * path, char * buf, int bufsize);
+extern int vu_rename (int * errn, const char * from, const char * to);
+extern int vu_rmdir (int * errn, const char * path);
+extern int vu_stat (int * errn, const char * path, struct stat * buf);
+extern int vu_symlink (int * errn, const char * from, const char * to);
+extern int vu_truncate (int * errn, const char * path, off_t where);
+extern int vu_unlink (int * errn, const char * path);
+extern int vu_utime (int * errn, const char * path, struct utimbuf * times);
+extern ssize_t vu_write (int * errn, int fd, const char * buf, size_t count);
+extern ssize_t vu_write_retry (int * errn, int fd, const char * buf, size_t count);
 extern int vu_fcntl (int * errn, int fd, int cmd, long arg);
 extern int vu_dup (int * errn, int fd);
 extern int vu_dup2 (int * errn, int fd, int newfd);
