@@ -182,7 +182,7 @@ arch_registered_archives (void)
           t_uchar * location = 0;
 
           location = arch_archive_location (f, 0);
-          rel_add_records (&answer, rel_make_record_2_taking (rel_get_field (files, x, 0), rel_make_field_str (location)), 0);
+          rel_add_records (&answer, rel_make_record_2_taking (rel_get_field (files, x, 0), rel_make_field_str (location)), rel_record_null);
 
           lim_free (0, location);
         }
