@@ -302,6 +302,10 @@ arch_evaluate_changeset (struct arch_changeset_report * report, t_uchar * path)
             dest = &report->file_metadata_changed;
             id_field = assoc_get_taking (mod_file_id_of, rel_make_field_str (patch_file_loc));
           }
+        else
+          {
+            id_field = rel_field_nil;
+          }
 
         if (dest && patch_file_loc)
           {
@@ -611,16 +615,23 @@ print_custom_diffs (int out_fd, struct arch_changeset_report * report, t_uchar *
       safe_printfmt ( out_fd, "* modified files\n\n");
       for (x = 0; x < rel_n_records (report->patched_regular_files); ++x)
         {
-          t_uchar * id = str_save(0, rel_peek_str(report->patched_regular_files, x, 1)) /*report->patched_regular_files[x][1]*/;
-          t_uchar * id2 = str_save(0, rel_peek_str(report->patched_regular_files, x, 0)) /*report->patched_regular_files[x][1]*/;
+          t_uchar *id = str_save(0, rel_peek_str(report->patched_regular_files, x, 1)) /*report->patched_regular_files[x][1]*/;
+          t_uchar *id2 = str_save(0, rel_peek_str(report->patched_regular_files, x, 0)) /*report->patched_regular_files[x][1]*/;
+
+          t_uchar *orig_part_path;
+          t_uchar *orig_path;
+          t_uchar *mod_path;
+
           key = rel_make_field_str(id);
+          
+          rel_field_ref(key);
 
-          t_uchar * orig_part_path = assoc_get_str_taking(orig_paths, key) /*assoc_ref(orig_paths, id)*/;
-          t_uchar * orig_path = file_name_in_vicinity(0, orig_dir, orig_part_path);
-          t_uchar * mod_path = file_name_in_vicinity(0, mod_dir, id2 /*report->patched_regular_files[x][0]*/);
-
-          arch_really_invoke_diff ( out_fd, orig_path,  orig_part_path, mod_path, id2 /*report->patched_regular_files[x][0]*/, (char **)opts);
-
+          orig_part_path = assoc_get_str_taking(orig_paths, key) /*assoc_ref(orig_paths, id)*/;
+          orig_path = file_name_in_vicinity(0, orig_dir, orig_part_path);
+          mod_path = file_name_in_vicinity(0, mod_dir, id2 /*report->patched_regular_files[x][0]*/);
+	  
+	  arch_really_invoke_diff ( out_fd, orig_path,  orig_part_path, mod_path, id2 /*report->patched_regular_files[x][0]*/, (char **)opts);
+	  
           rel_field_unref(key);
           lim_free(0, mod_path);
           lim_free(0, orig_path);
