@@ -410,7 +410,7 @@ arch_cmd_abrowse (t_uchar * program_name, int argc, char * argv[])
               {
                 level = arch_parse_package_name (arch_ret_patch_level, 0, rev);
                 assoc_set_taking (&since_limits, rel_make_field_str (version), rel_make_field_str (level));
-                rel_add_records (&old_since_limits, rel_make_record_2_taking (rel_make_field_str (version), rel_make_field_str (level)), 0);
+                rel_add_records (&old_since_limits, rel_make_record_2_taking (rel_make_field_str (version), rel_make_field_str (level)), rel_record_null);
               }
 
             if (since_limits_opt)
@@ -550,7 +550,7 @@ arch_cmd_abrowse (t_uchar * program_name, int argc, char * argv[])
                                     rel_add_records (&new_since_limits,
                                                      rel_make_record_2_taking (rel_get_field (versions, v, 0),
                                                                                rel_get_field (revisions, 0, 0)),
-                                                     0);
+                                                     rel_record_null);
                                 }
                               else
                                 {
@@ -558,7 +558,7 @@ arch_cmd_abrowse (t_uchar * program_name, int argc, char * argv[])
                                     rel_add_records (&new_since_limits,
                                                      rel_make_record_2_taking (rel_get_field (versions, v, 0),
                                                                                rel_get_field (revisions, rel_n_records (revisions) - 1, 0)),
-                                                     0);
+                                                     rel_record_null);
                                 }
 
                               for (r = 0; r < rel_n_records (revisions); ++r)
