@@ -15,6 +15,7 @@
 #include "tla/libarch/patch-logs.h"
 #include "tla/libarch/cmd.h"
 #include "tla/libarch/cmd-cat-log.h"
+#include "tla/libarch/cmdutils.h"
 
 
 
@@ -121,8 +122,6 @@ arch_cmd_cat_log (t_uchar * program_name, int argc, char * argv[])
     t_uchar * revision = 0;
     t_uchar * log_path = 0;
 
-    revision_spec = argv[1];
-
     if (default_archive)
       {
         if (!arch_valid_archive_name (default_archive))
@@ -141,31 +140,9 @@ arch_cmd_cat_log (t_uchar * program_name, int argc, char * argv[])
         exit (1);
       }
 
-    if (arch_valid_patch_level_name (revision_spec))
-      {
-        t_uchar * tree_version = 0;
-        t_uchar * version = 0;
-
-        tree_version = arch_tree_version (tree_root);
-
-        archive = arch_parse_package_name (arch_ret_archive, default_archive, tree_version);
-        version = arch_parse_package_name (arch_ret_non_archive, 0, tree_version);
-        revision = str_alloc_cat_many (0, version, "--", revision_spec, str_end);
-
-        lim_free (0, tree_version);
-        lim_free (0, version);
-      }
-    else if (!arch_valid_package_name (revision_spec, arch_maybe_archive, arch_req_patch_level, 0))
-      {
-        safe_printfmt (2, "%s: invalid revision name (%s)\n",
-                       argv[0], revision_spec);
-        exit (1);
-      }
-    else
-      {
-        archive = arch_parse_package_name (arch_ret_archive, default_archive, revision_spec);
-        revision = arch_parse_package_name (arch_ret_non_archive, 0, revision_spec);
-      }
+    revision_spec = arch_fqrvsn_from_tree_and_input (argv[0], argv[1], tree_root);
+    archive = arch_parse_package_name (arch_ret_archive, default_archive, revision_spec);
+    revision = arch_parse_package_name (arch_ret_non_archive, 0, revision_spec);
 
     log_path = arch_log_file (tree_root, archive, revision);
 
