@@ -123,6 +123,12 @@ arch_cmd_make_category (t_uchar * program_name, int argc, char * argv[])
         exit (2);
       }
 
+    if (arch_is_system_package_name (cat_spec))
+      {
+        safe_printfmt (2, "%s: user's can not create system categories\n  category: %s\n", argv[0], cat_spec);
+        exit (2);
+      }
+
     archive = arch_parse_package_name (arch_ret_archive, default_archive, cat_spec);
     cat = arch_parse_package_name (arch_ret_category, 0, cat_spec);
 
