@@ -279,7 +279,7 @@ arch_cmd_rbrowse (t_uchar * program_name,
 
   if (! all_archives)
     {
-      rel_add_records (&archive_list, rel_singleton_record_taking (rel_make_field_str (default_archive)), 0);
+      rel_add_records (&archive_list, rel_singleton_record_taking (rel_make_field_str (default_archive)), rel_record_null);
     }
   else
     {
@@ -525,7 +525,7 @@ rbrowse_patchlog (struct arch_archive * arch,
           
           if (regexec (&patch_regex_needle, summary, 0, 0, 0) == 0)
             {
-              rel_add_records (&patch_output, rel_singleton_record_taking (rel_make_field_str (log)), 0);
+              rel_add_records (&patch_output, rel_singleton_record_taking (rel_make_field_str (log)), rel_record_null);
             }
 
           lim_free(0, summary);
@@ -592,7 +592,7 @@ rbrowse_build_since_table (struct arch_archive *arch,
   t_uchar *latest_revision;
   
   latest_revision = arch_archive_latest_revision (arch, version, 1);
-  rel_add_records (since_output, rel_singleton_record_taking (rel_make_field_str (latest_revision)),0);
+  rel_add_records (since_output, rel_singleton_record_taking (rel_make_field_str (latest_revision)),rel_record_null);
   lim_free(0, latest_revision);
 
 }
