@@ -24,7 +24,7 @@
 
 
 /* __STDC__ prototypes for static functions */
-static void redo_callback (void * ign, char * fmt, va_list ap);
+static void redo_callback (void * ign, const char * fmt, va_list ap);
 
 
 
@@ -227,7 +227,7 @@ arch_cmd_redo (t_uchar * program_name, int argc, char * argv[])
 
 
 static void
-redo_callback (void * ign, char * fmt, va_list ap)
+redo_callback (void * ign, const char * fmt, va_list ap)
 {
   safe_printfmt_va_list (1, fmt, ap);
   safe_flush (1);
