@@ -11,6 +11,7 @@
 #include "config-options.h"
 #include "hackerlab/cmd/main.h"
 #include "tla/libarch/changeset-report.h"
+#include "tla/libarch/cmd.h"
 #include "tla/libarch/cmd-show-changeset.h"
 
 
@@ -39,7 +40,10 @@ static t_uchar * version_string = (cfg__std__package " from regexps.com\n"
       "Display a release identifier string\n" \
       "and exit.") \
   OP (opt_diffs, 0, "diffs", 0, \
-      "include diff output")
+      "include diff output") \
+  OP (opt_unescaped, 0, "unescaped", 0, \
+      "show filenames in unescaped form")
+
 
 t_uchar arch_cmd_show_changeset_help[] = ("generate a report from a changeset\n"
                                           "Produce a human-readable summary of a changeset.\n");
@@ -63,6 +67,7 @@ arch_cmd_show_changeset (t_uchar * program_name, int argc, char * argv[])
   int o;
   struct opt_parsed * option;
   int diffs;
+  int escape_classes = arch_escape_classes;
 
   diffs = 0;
 
@@ -95,6 +100,12 @@ arch_cmd_show_changeset (t_uchar * program_name, int argc, char * argv[])
             diffs = 1;
             break;
           }
+
+	case opt_unescaped:
+	  {
+	    escape_classes = 0;
+	    break;
+	  }
         }
     }
 
@@ -106,7 +117,7 @@ arch_cmd_show_changeset (t_uchar * program_name, int argc, char * argv[])
 
     mem_set0 ((t_uchar *)&report, sizeof (report));
     arch_evaluate_changeset (&report, argv[1]);
-    arch_print_changeset (1, &report, diffs);
+    arch_print_changeset (1, &report, diffs, escape_classes);
   }
 
   return 0;
