@@ -669,31 +669,35 @@ arch_generate_id (void)
 }
 
 
-void
+int
 arch_add_explicit_id (const t_uchar * path,
                       const t_uchar * id)
 {
   t_uchar * id_file;
   t_uchar * id_dir;
   int out_fd;
-
+  int r = 1;
+  
   id_file = arch_explicit_id_file_for (path);
 
   if (!safe_access (id_file, F_OK))
     {
       safe_printfmt (2, "attempt to id already tagged file: %s\n", path);
-      exit (2);
+      r = 0;
     }
+  else
+    {
+      id_dir = file_name_directory_file (0, id_file);
 
-  id_dir = file_name_directory_file (0, id_file);
-
-  ensure_directory_exists (id_dir);
-  out_fd = safe_open (id_file, O_WRONLY | O_CREAT | O_EXCL, 0666);
-  safe_printfmt (out_fd, "%s\n", id);
-  safe_close (out_fd);
-
+      ensure_directory_exists (id_dir);
+      out_fd = safe_open (id_file, O_WRONLY | O_CREAT | O_EXCL, 0666);
+      safe_printfmt (out_fd, "%s\n", id);
+      safe_close (out_fd);
+      lim_free (0, id_dir);
+    }
   lim_free (0, id_file);
-  lim_free (0, id_dir);
+  return r;
+  
 }
 
 
