@@ -488,7 +488,7 @@ arch_set_my_library_path (enum arch_library_path_type path_type,
    */
   if (dir_spec && (op == arch_library_first))
     {
-      rel_add_records (&new_path, rel_singleton_record_taking (rel_make_field_str (dir)), 0);
+      rel_add_records (&new_path, rel_singleton_record_taking (rel_make_field_str (dir)), rel_record_null);
     }
 
   /* copy the old path, removing dir_spec (if any)
@@ -501,7 +501,7 @@ arch_set_my_library_path (enum arch_library_path_type path_type,
         {
           if (str_cmp (rel_peek_str (old_path, x, 0), dir))
             {
-              rel_add_records (&new_path, rel_singleton_record_taking (rel_get_field (old_path, x, 0)), 0);
+              rel_add_records (&new_path, rel_singleton_record_taking (rel_get_field (old_path, x, 0)), rel_record_null);
             }
         }
     }
@@ -510,7 +510,7 @@ arch_set_my_library_path (enum arch_library_path_type path_type,
    */
   if (dir_spec && (op == arch_library_last))
     {
-      rel_add_records (&new_path, rel_singleton_record_taking (rel_make_field_str (dir)), 0);
+      rel_add_records (&new_path, rel_singleton_record_taking (rel_make_field_str (dir)), rel_record_null);
     }
 
 
