@@ -15,6 +15,7 @@
 #include "hackerlab/os/signal.h"
 #include "hackerlab/char/str.h"
 #include "hackerlab/hash/md5-utils.h"
+#include "hackerlab/hash/sha1-utils.h"
 #include "hackerlab/rx-posix/regex.h"
 #include "hackerlab/vu/safe.h"
 #include "hackerlab/fs/file-names.h"
@@ -492,6 +493,13 @@ static assoc_table remembered_md5s = 0;
  * values are (ascii, hex) md5 checksums.
  */
 
+static assoc_table remembered_sha1s = 0;
+/*
+ * keys are
+ * 		$url $revision $file
+ * 
+ * values are (ascii, hex) SHA1 checksums.
+ */
 
 static assoc_table checked_revisions = 0;
 /*
@@ -666,15 +674,106 @@ arch_pfs_ensure_checksum_data (struct arch_pfs_archive * arch,
   return answer;
 }
 
+static void
+arch_pfs_insert_key (t_uchar *line, t_uchar *key_prefix, regmatch_t *file, regmatch_t *hash, assoc_table *table)
+{
+  t_uchar * file_name = 0;
+  t_uchar * assoc_key = 0;
+  t_uchar * val = 0;
+  
+  file_name = str_save_n (0, line + file->rm_so, file->rm_eo - file->rm_so);
+  assoc_key = str_alloc_cat (0, key_prefix, file_name);
+  val = str_save_n (0, line + hash->rm_so, hash->rm_eo - hash->rm_so);
+  
+  assoc_set_taking (table, rel_make_field_str(assoc_key), rel_make_field_str(val));
+  
+  lim_free (0, file_name);
+  lim_free (0, assoc_key);
+  lim_free (0, val);
+}
+
 
 static int
 arch_pfs_memoize_checksum_file (const t_uchar * archive,
                                 const t_uchar * official_archive,
                                 const t_uchar * revision,
                                 const t_uchar * file_contents)
+{
+  static char file_head_pattern[] = "^Signature-for: ([^/]+)/(.+)$";
+  static char md5_pattern[] = "^md5 ([^\n ]+) ([a-f0-9]+)";
+  static char sha1_pattern[] = "^sha1 ([^\n ]+) ([a-f0-9]+)";
+  static int is_compiled = 0;
+  static regex_t file_head_preg;
+  static regex_t md5_preg;
+  static regex_t sha1_preg;
+
+  regmatch_t pmatch[3];
+
+  if (!is_compiled)
+    {
+      if (regcomp (&file_head_preg, file_head_pattern, REG_EXTENDED | REG_NEWLINE))
+        panic ("unable to compile checksum-file head regexp");
+      if (regcomp (&md5_preg, md5_pattern, REG_EXTENDED))
+        panic ("unable to compile checksum-file MD5 regexp");
+      if (regcomp (&sha1_preg, sha1_pattern, REG_EXTENDED))
+        panic ("unable to compile checksum-file SHA1 regexp");
+      is_compiled = 1;
+    }
+
+  if (regexec (&file_head_preg, file_contents, 3, pmatch, 0))
+    return -1;
+
+  if (str_cmp_n (official_archive, str_length (official_archive),
+                 file_contents + pmatch[1].rm_so, (pmatch[1].rm_eo - pmatch[1].rm_so)))
+    return -1;
+
+  if (str_cmp_n (revision, str_length (revision),
+                 file_contents + pmatch[2].rm_so, (pmatch[2].rm_eo - pmatch[2].rm_so)))
+    return -1;
+
+
+  {
+    t_uchar * key_prefix = 0;
+    /* so this is the URL to the revision, for all intents and purposes 
+     * so it should be location not archive-name
+     */
+    invariant (archive != NULL);
+    key_prefix = str_alloc_cat_many (0, archive, " ", revision, " ", str_end);
+
+    file_contents = str_chr_index (file_contents, '\n');
+    if (file_contents)
+      file_contents++;
+  
+    while (file_contents && *file_contents)
+      {
+	if (!regexec (&md5_preg, file_contents, 3, pmatch, 0))
+	  arch_pfs_insert_key (file_contents, key_prefix, &pmatch[1], &pmatch[2], &remembered_md5s);
+	else if (!regexec (&sha1_preg, file_contents, 3, pmatch, 0))
+	  arch_pfs_insert_key (file_contents, key_prefix, &pmatch[1], &pmatch[2], &remembered_sha1s);
+	else
+	  ; /*
+	     * Ignore this line for now; it may be another hash or other metadata
+	     * that was added by a future tla version.
+	     */
+	  
+	file_contents = str_chr_index (file_contents, '\n');
+	if (file_contents)
+	  file_contents++;
+      }
+      
+    lim_free (0, key_prefix);
+  }
+
+  return 0;
+}
+                                
+                                
+#if 0                                
 {
   static char file_pattern[] = ("^Signature-for: (.*)/(.*)\n"
                                 "([[:(md5 [^/[:space:]]+ ................................\n):]]*)");
+  static char md5_pattern[] = "^md5 ([^\n ]+) ([a-f0-9]+)";
+  static char sha1_pattern[] = "^sha1 ([^\n ]+) ([a-f0-9]+)";
   static int is_compiled = 0;
   static regex_t preg;
 
@@ -738,7 +837,7 @@ arch_pfs_memoize_checksum_file (const t_uchar * archive,
 
   return 0;
 }
-
+#endif
 
 int
 arch_pfs_checksum_anticipates_file (const t_uchar * archive,
@@ -750,6 +849,11 @@ arch_pfs_checksum_anticipates_file (const t_uchar * archive,
 
   key = str_alloc_cat_many (0, archive, " ", revision, " ", file, str_end);
 
+  /*
+   * Only MD5 is required for now.  Perhaps at a later point we will
+   * also require SHA1.
+   */
+
   answer = !!assoc_get_str_taking (remembered_md5s, rel_make_field_str (key));
 
   lim_free (0, key);
@@ -798,6 +902,46 @@ arch_pfs_checksum_governs_strictly (struct arch_pfs_archive * arch)
 }
 
 
+static void
+arch_pfs_validate_checksums (struct arch_archive *arch, t_uchar *revision, t_uchar *tail, t_uchar *key, t_uchar *contents_md5, t_uchar *contents_sha1)
+{
+      t_uchar * remembered_md5 = 0;
+      t_uchar * remembered_sha1 = 0;
+
+      remembered_md5 = assoc_get_str_taking (remembered_md5s, rel_make_field_str (key));
+      remembered_sha1 = assoc_get_str_taking (remembered_sha1s, rel_make_field_str (key));
+
+      if ((remembered_md5 && str_cmp (remembered_md5, contents_md5))
+	  || (remembered_sha1 && str_cmp (remembered_sha1, contents_sha1)))
+        {
+          safe_printfmt (2, ("\n"
+                             "********************************\n"
+                             " MISMATCHED ARCHIVE CHECKSUM\n"
+                             "\n"
+                             "  archive: %s\n"
+                             "  revision: %s\n"
+			     "  url: %s\n"
+                             "  file: %s\n"
+                             "\n"
+                             "  expected:\n"), arch->official_name, revision, arch->location, tail);
+
+	  if (remembered_md5)
+	    safe_printfmt (2, (" MD5: %s\n"), remembered_md5);
+	  if (remembered_sha1)
+	    safe_printfmt (2, (" SHA1: %s\n"), remembered_sha1);
+	  safe_printfmt (2, ("  got:\n"));
+	  if (remembered_md5)
+	    safe_printfmt (2, (" MD5: %s\n"), contents_md5);
+	  if (remembered_sha1)
+	    safe_printfmt (2, (" SHA1: %s\n"), contents_sha1);
+	  safe_printfmt (2, ("\n"
+                             "********************************\n"
+                             "\n"));
+          exit (2);
+        }
+}
+
+
 t_uchar *
 arch_pfs_checked_file_contents (struct arch_pfs_archive * arch,
                                 const t_uchar * revision,
@@ -812,6 +956,7 @@ arch_pfs_checked_file_contents (struct arch_pfs_archive * arch,
       const t_uchar * remembered_md5;
       t_uchar * contents = 0;
       t_uchar * contents_md5 = 0;
+      t_uchar * contents_sha1 = 0;
 
       tail = file_name_tail (0, path);
       key = str_alloc_cat_many (0, arch->arch.name, " ", revision, " ", tail, str_end);
@@ -819,29 +964,14 @@ arch_pfs_checked_file_contents (struct arch_pfs_archive * arch,
 
       contents = arch_pfs_file_contents (arch->pfs, path, 0);
       contents_md5 = md5_ascii_for_str (0, contents);
+      contents_sha1 = sha1_ascii_for_str (0, contents);
 
-      if (remembered_md5 && str_cmp (remembered_md5, contents_md5))
-        {
-          safe_printfmt (2, ("\n"
-                             "********************************\n"
-                             " MISMATCHED ARCHIVE CHECKSUM\n"
-                             "\n"
-                             "  archive: %s\n"
-                             "  revision: %s\n"
-                             "  file: %s\n"
-                             "\n"
-                             "  expected: %s\n"
-                             "  got: %s\n"
-                             "\n"
-                             "********************************\n"
-                             "\n"),
-                         arch->arch.name, revision, tail, remembered_md5, contents_md5);
-          exit (2);
-        }
+      arch_pfs_validate_checksums (&arch->arch, revision, tail, key, contents_md5, contents_sha1);
 
       lim_free (0, tail);
       lim_free (0, key);
       lim_free (0, contents_md5);
+      lim_free (0, contents_sha1);
 
       return contents;
     }
@@ -865,8 +995,11 @@ arch_pfs_checked_get_file (struct arch_pfs_archive * arch,
       int tmp_fd = -1;
       t_uchar buf[1 << 16];
       md5_context_t md5c = 0;
+      sha1_context_t sha1c = 0;
       t_uchar computed_md5_raw[16];
+      t_uchar computed_sha1_raw[20];
       t_uchar * computed_md5 = 0;
+      t_uchar * computed_sha1 = 0;
       
       tail = file_name_tail (0, path);
       key = str_alloc_cat_many (0, arch->arch.name, " ", revision, " ", tail, str_end);
@@ -879,6 +1012,7 @@ arch_pfs_checked_get_file (struct arch_pfs_archive * arch,
       safe_lseek (tmp_fd, (off_t)0, SEEK_SET);
 
       md5c = make_md5_context (0);
+      sha1c = make_sha1_context (0);
 
       while (1)
         {
@@ -891,31 +1025,17 @@ arch_pfs_checked_get_file (struct arch_pfs_archive * arch,
           else
             {
               md5_scan (md5c, buf, (size_t)amt);
+              sha1_scan (sha1c, buf, (size_t)amt);
               safe_write_retry (out_fd, buf, (size_t)amt);
             }
         }
 
       md5_final (computed_md5_raw, md5c);
+      sha1_final (computed_sha1_raw, sha1c);
       computed_md5 = md5_alloc_ascii (0, computed_md5_raw);
+      computed_sha1 = sha1_alloc_ascii (0, computed_sha1_raw);
 
-      if (remembered_md5 && str_cmp (remembered_md5, computed_md5))
-        {
-          safe_printfmt (2, ("\n"
-                             "********************************\n"
-                             " MISMATCHED ARCHIVE CHECKSUM\n"
-                             "\n"
-                             "  archive: %s\n"
-                             "  revision: %s\n"
-                             "  file: %s\n"
-                             "\n"
-                             "  expected: %s\n"
-                             "  got: %s\n"
-                             "\n"
-                             "********************************\n"
-                             "\n"),
-                         arch->arch.name, revision, tail, remembered_md5, computed_md5);
-          exit (2);
-        }
+      arch_pfs_validate_checksums (&arch->arch, revision, tail, key, computed_md5, computed_sha1);
 
       lim_free (0, tail);
       lim_free (0, key);
