@@ -392,7 +392,12 @@ arch_pfs_update_listing_file (struct arch_pfs_session * session,
 
       for (x = 0; x < rel_n_records (files_before); ++x)
         {
-          if (('.' != rel_peek_str (files_before, x, 0)[0]) && (',' != rel_peek_str (files_before, x, 0)[0]))
+          const t_uchar * file_name;
+
+          file_name = rel_peek_str (files_before, x, 0);
+
+          if (   (('.' != file_name[0]) && (',' != file_name[0]))
+              || !str_cmp (".archive-version", file_name))
             {
               safe_printfmt (tmp_fd, "%s\r\n", rel_peek_str (files_before, x, 0));
             }
