@@ -329,7 +329,7 @@ rel_make_record_8_taking (rel_field f0,
   return answer;
 }
 
-const rel_record rel_record_null;
+const rel_record rel_record_null = { 0 } ; /* make this equivalent with rec_record_nil... maybe they are meant to be the same and should be a single variable? */ 
 
 void
 rel_add_records (rel_table * table, ...)
@@ -976,8 +976,8 @@ rel_join (int absence_table,
           int x;
 
           r = rel_record_nil;
-          f1_rec = ((f1_pos < f1_len) ? table1._r[f1_pos] : rel_record_nil);
-          f2_rec = ((f2_pos < f2_len) ? table2._r[f2_pos] : rel_record_nil);
+          f1_rec = ((f1_pos < f1_len) ? table1._r[f1_pos] : r);
+          f2_rec = ((f2_pos < f2_len) ? table2._r[f2_pos] : r);
           for (x = 0; x < n_output_fields; ++x)
             {
               rel_field field;
@@ -1286,6 +1286,47 @@ rel_print_pika_escape_iso8859_1_record_sp (int fd, int escape_classes, rel_recor
     safe_printfmt (fd, "\n");
 }
 
+rel_table 
+rel_table_substract (rel_table t, rel_table t2)
+{
+  rel_table answer = rel_table_nil;
+  int lim;
+  int x;
+
+  lim = rel_n_records (t);
+
+  for (x = 0; x < lim; ++x)
+    {
+      if (!rel_table_contains(t2, t._r[x]))
+          *(rel_record *)ar_push ((void **)&answer._r, 0, sizeof (rel_record)) = rel_copy_record (t._r[x]);
+    }
+
+  return answer;
+}
+
+int
+rel_table_contains(rel_table t, rel_record  r)
+{ /* assuming the table is one column only */
+  int lim;
+  int x;
+  t_dstr d1;
+  t_dstr d2;
+  
+  d2 = r._c[0]._d;
+  
+  lim = rel_n_records(t);
+  
+  for (x = 0; x < lim; x++)
+    {
+       d1 = t._r[x]._c[0]._d;
+       if (dstr_cmp(d1, d2) == 0)
+           return 1;
+
+    }
+  return 0;
+
+}
+
 
 
 
