@@ -13,7 +13,7 @@ srcdir=`dirname "$arg0"`
 
 . ${srcdir}/test-framework
 
-setup_with_trivial_archives
+setup_with_trivial_tla_archives
 
 test_class "file-diffs"
 
